package workload_test

import (
	"os"
	"testing"

	"git.badhouseplants.net/allanger/shoebill/pkg/types/workload"
	"git.badhouseplants.net/allanger/shoebill/utils/helpers"
	"github.com/stretchr/testify/assert"
)

func TestUnitReadValidFile(t *testing.T) {
	f := helpers.CreateFile(t)
	defer os.Remove(f.Name())

	const validFile = `---
kind: Deployment
replicas: 1
containers:
  - name: controller
    image: {{ .Image }}
    imagePullPolicy: Always
`
	helpers.FillFile(t, f, validFile)

	workload, err := workload.ReadFromFile(f.Name())

	// Check that there is no unexpected error
	assert.NoError(t, err)

	// Check the bundle metadata
	assert.Equal(t, "Deployment", workload.Kind)
	assert.Equal(t, 1, workload.Replicas)

}

func TestUnitKindValidatorDeployment(t *testing.T) {
	wd := &workload.Workload{
		Kind: "Deployment",
	}
	err := wd.ValidateKind()
	assert.NoError(t, err)
}

func TestUnitKindValidatorStatefulSet(t *testing.T) {
	wd := &workload.Workload{
		Kind: "StatefulSet",
	}
	err := wd.ValidateKind()
	assert.NoError(t, err)
}

func TestUnitKindValidatorDeamonSet(t *testing.T) {
	wd := &workload.Workload{
		Kind: "DaemonSet",
	}
	err := wd.ValidateKind()
	assert.NoError(t, err)
}

func TestUnitKindValidatorInvalid(t *testing.T) {
	wd := &workload.Workload{
		Kind: "Invalid",
	}
	err := wd.ValidateKind()
	assert.ErrorContains(t, err, "got Invalid")
}
